package net.idscan.android.pdf417scannerexample;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import net.idscan.android.dlparser.DLParser;
import net.idscan.android.pdf417scanner.PDF417ScanActivity;

import java.io.UnsupportedEncodingException;

public class MainActivity extends FragmentActivity {
	private final static int SCAN_ACTIVITY_CODE = 0x001;
	private DLParser parser = null;

	/**
	 * UI elements.
	 */
	private TextView _tv_result;
	private Button _btn_parse;

	/**
	 * License key for scanner and parser.
	 */
	private static final String SCANNER_KEY = "";
	private static final String PARSER_KEY = "";

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		_tv_result = (TextView) findViewById(R.id.tv_result);

		Button _btn_scan = (Button) findViewById(R.id.btn_scan);
		_btn_scan.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				Intent i = new Intent(MainActivity.this, PDF417ScanActivity.class);
				i.putExtra(PDF417ScanActivity.EXTRA_LICENSE_KEY, SCANNER_KEY);

				startActivityForResult(i, SCAN_ACTIVITY_CODE);
			}
		});

		_btn_parse = (Button) findViewById(R.id.btn_parse);
		_btn_parse.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				parser = new DLParser();
				try {
					//setup parser.
					parser.setup(getApplicationContext(), PARSER_KEY);
					//make parse the data.
					DLParser.DLResult res = parser.parse(_tv_result.getText().toString().getBytes("UTF8"));
					_tv_result.setText("Name: " + res.fullName);
					_tv_result.append("\n" + "Address: " + res.address1);
					_tv_result.append("\n" + "Birth Date: " + res.birthdate);
					_tv_result.append("\n" + "City: " + res.city);
					_tv_result.append("\n" + "Country: " + res.country);
				} catch (DLParser.DLParserException e) {
					e.printStackTrace();
				} catch (UnsupportedEncodingException e) {
					e.printStackTrace();
				}
			}
		});
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
	}

	@Override
	protected void onResume() {
		super.onResume();
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);

		if (requestCode == SCAN_ACTIVITY_CODE) {
			if (resultCode == PDF417ScanActivity.RESULT_OK) {
				if (data != null)
					_tv_result.setText(data.getStringExtra(PDF417ScanActivity.BARCODE_DATA));
			} else if (resultCode == PDF417ScanActivity.ERROR_INVALID_CAMERA_NUMBER) {
				_tv_result.setText("Invalid camera number.");
			} else if (resultCode == PDF417ScanActivity.ERROR_CAMERA_NOT_AVAILABLE) {
				_tv_result.setText("Camera not available.");
			} else if (resultCode == PDF417ScanActivity.ERROR_INVALID_CAMERA_ACCESS) {
				_tv_result.setText("Invalid camera access.");
			} else if (resultCode == PDF417ScanActivity.ERROR_INVALID_LICENSE_KEY) {
				_tv_result.setText("Invalid license key.");
			}
		}
	}
}